![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)

[![License: MIT](https://img.shields.io/badge/License-MIT-brightgreen.svg)](https://opensource.org/licenses/MIT)
![Platform](https://img.shields.io/badge/Platform-Linux%2C%20Windows%2C%20macOS-blue)
![Github Issues](https://img.shields.io/github/issues-closed/Akshay-Dongare/langchain-litellm)
![Github Issues](https://img.shields.io/github/issues/Akshay-Dongare/langchain-litellm)
![Github Pull Requests](https://img.shields.io/github/issues-pr/Akshay-Dongare/langchain-litellm)
![Github Pull Requests](https://img.shields.io/github/issues-pr-closed/Akshay-Dongare/langchain-litellm)

# [langchain-litellm](https://pypi.org/project/langchain-litellm/)

This package contains the [LangChain](https://github.com/langchain-ai/langchain) integration with LiteLLM. [LiteLLM](https://github.com/BerriAI/litellm) is a library that simplifies calling Anthropic, Azure, Huggingface, Replicate, etc.

## Installation and setup

```bash
pip install langchain-litellm
```

## Chat Models
```python
from langchain_litellm import ChatLiteLLM
```
See a [usage example](https://github.com/Akshay-Dongare/langchain-litellm/blob/main/docs/litellm.ipynb)
